<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>Converter</name>
    <message>
        <location filename="../src/converter.cpp" line="69"/>
        <source>Skipped: %1 already esists.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/converter.cpp" line="89"/>
        <location filename="../src/converter.cpp" line="99"/>
        <location filename="../src/converter.cpp" line="106"/>
        <source>Error: %1</source>
        <translation>Помилка: %1</translation>
    </message>
    <message>
        <location filename="../src/converter.cpp" line="290"/>
        <source>ERROR: Format %1 is not supported for writing, choose another output format. Skipping!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogConversionStatus</name>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="96"/>
        <location filename="../ui/dialogconversionstatus.ui" line="131"/>
        <location filename="../ui/dialogconversionstatus.ui" line="166"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="233"/>
        <source>Close</source>
        <translation>Зачинити</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="85"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Total:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Всього:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="61"/>
        <source>Image:</source>
        <translation>Зображення:</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="14"/>
        <source>Status...</source>
        <translation>Стан…</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="20"/>
        <source>Conversion Status</source>
        <translation>Стан перетворення</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="66"/>
        <source>Status:</source>
        <translation>Стан:</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="120"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Converted:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Перетворено:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="155"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Errors:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Помилки:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="206"/>
        <source>Open destination </source>
        <translation>Відкрити місце призначення</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="226"/>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <location filename="../src/dialogconversionstatus.cpp" line="41"/>
        <source>Open all the destination folders</source>
        <translation>Відкрити всі теки призначення</translation>
    </message>
    <message>
        <location filename="../src/dialogconversionstatus.cpp" line="77"/>
        <source>Converted</source>
        <translation>Перетворено</translation>
    </message>
</context>
<context>
    <name>DialogInfo</name>
    <message>
        <location filename="../ui/dialoginfo.ui" line="455"/>
        <source>Close</source>
        <translation>Зачинити</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="26"/>
        <source>About Converseen...</source>
        <translation>Про Converseen…</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="105"/>
        <source>Informations</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="127"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Translators:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Перекладачі:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="50"/>
        <location filename="../ui/dialoginfo.ui" line="73"/>
        <location filename="../ui/dialoginfo.ui" line="86"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="59"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Converseen is an image batch conversion tool. You can resize and convert images in more than 100 different formats.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Converseen — це пакетний перетворювач графічних файлів. Ви маєте можливість змінювати розмір та конвертувати зображення в більше ніж 100 форматів.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/dialoginfo.cpp" line="54"/>
        <source>The batch image converter and resizer.</source>
        <translation>Груповий перетворювач графічних файлів.</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="251"/>
        <source>&lt;strong&gt;Ukrainian translation: &lt;/strong&gt;AleXKaN - &lt;a href=&quot;mailto:aws2@india.com&quot;&gt;aws2@india.com&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Переклад на українську мову: &lt;/strong&gt;AleXKaN — &lt;a href=&quot;mailto:aws2@india.com&quot;&gt;aws2@india.com&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="162"/>
        <source>&lt;strong&gt;Hungarian translation: &lt;/strong&gt;Charles Barcza - &lt;a href=&quot;mailto:kbarcza@blackpanther.hu&quot;&gt;kbarcza@blackpanther.hu&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Переклад на угорську мову: &lt;/strong&gt;Charles Barcza — &lt;a href=&quot;mailto:kbarcza@blackpanther.hu&quot;&gt;kbarcza@blackpanther.hu&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="169"/>
        <source>&lt;strong&gt;Czech translation: &lt;/strong&gt;Pavel Fric - &lt;a href=&quot;mailto:pavelfric@seznam.cz&quot;&gt;pavelfric@seznam.cz&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Переклад на чеську мову: &lt;/strong&gt;Pavel Fric — &lt;a href=&quot;mailto:pavelfric@seznam.cz&quot;&gt;pavelfric@seznam.cz&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="193"/>
        <source>&lt;strong&gt;German Translation: &lt;/strong&gt;Marco Nickolai - &lt;a href=&quot;mailto:nickolai@iad.tu-darmstadt.de&quot;&gt;nickolai@iad.tu-darmstadt.de&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Переклад на німецьку мову: &lt;/strong&gt;Marco Nickolai — &lt;a href=&quot;mailto:nickolai@iad.tu-darmstadt.de&quot;&gt;nickolai@iad.tu-darmstadt.de&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="369"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Follow Converseen:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Следите за Converseen:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="227"/>
        <source>&lt;strong&gt;Polish Translation: &lt;/strong&gt;Michał Olber from OSWorld.pl - &lt;a href=&quot;mailto:redakcja@osworld.pl&quot;&gt;redakcja@osworld.pl&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Переклад на польську мову: &lt;/strong&gt;Michał Olber from OSWorld.pl — &lt;a href=&quot;mailto:redakcja@osworld.pl&quot;&gt;redakcja@osworld.pl&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="183"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Brazilian Portuguese Translation: &lt;/span&gt;Paulo Guzmán - &lt;a href=&quot;mailto:white.hat@msn.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;white.hat@msn.com&lt;/span&gt;&lt;/a&gt; -&lt;span style=&quot; font-weight:600;&quot;/&gt;Márcio Moraes - &lt;a href=&quot;mailto:marciopanto@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;marciopanto@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Бразильський португальський переклад: &lt;/span&gt;Paulo Guzmán - &lt;a href=&quot;mailto:white.hat@msn.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;white.hat@msn.com&lt;/span&gt;&lt;/a&gt; -&lt;span style=&quot; font-weight:600;&quot;/&gt;Márcio Moraes - &lt;a href=&quot;mailto:marciopanto@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;marciopanto@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="217"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Russian Translation: &lt;/span&gt;&lt;a href=&quot;https://github.com/alevtina-karashokova&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Alevtina Karashokova&lt;/span&gt;&lt;/a&gt;, Stasik Savorovsky - &lt;a href=&quot;mailto:stas_stv@mail.ru&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;stas_stv@mail.ru&lt;/span&gt;&lt;/a&gt;, Kyrill Detinov - &lt;a href=&quot;mailto:lazy.kent@opensuse.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;lazy.kent@opensuse.org&lt;/span&gt;&lt;/a&gt;, ViktorOn - &lt;a href=&quot;https://github.com/ViktorOn&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;ViktorOn&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="237"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Japanese translation:&lt;/span&gt; Xenolith0 - &lt;a href=&quot;mailto:xenolith0bytetestcomgreen@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;xenolith0bytetestcomgreen@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Японський переклад:&lt;/span&gt; Xenolith0 - &lt;a href=&quot;mailto:xenolith0bytetestcomgreen@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;xenolith0bytetestcomgreen@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="244"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Danish translation: &lt;/span&gt;Martin Eilsoe - &lt;a href=&quot;mailto:martin.eilsoe@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;martin.eilsoe@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Датський переклад: &lt;/span&gt;Martin Eilsoe - &lt;a href=&quot;mailto:martin.eilsoe@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;martin.eilsoe@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="281"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;If you appreciate this work and would like to support the project, you are welcome to donate via PayPal&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Якщо Ви цінуєте цю роботу та бажаєте підтримати проект, Ви можете пожертвувати нам через Paypal&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/dialoginfo.cpp" line="40"/>
        <source>ImageMagick Version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="258"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Swedish translation: &lt;/span&gt;Åke Engelbrektson - &lt;a href=&quot;mailto:eson@svenskasprakfiler.se&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;eson@svenskasprakfiler.se&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="265"/>
        <source>&lt;strong&gt;Simplified Chinese translation: &lt;/strong&gt;myd7349 - &lt;a href=&quot;mailto:myd7349@gmail.com&quot;&gt;myd7349@gmail.com&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="111"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Author: &lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Francesco Mondello (Faster) - &lt;/span&gt;&lt;a href=&quot;https://fasterland.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;fasterland.net&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Email: &lt;/span&gt;&lt;a href=&quot;faster3ck@gmail.com&quot;&gt;&lt;span style=&quot; font-size:10pt; text-decoration: underline; &quot;&gt;faster3ck@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Project Website: &lt;/span&gt;&lt;a href=&quot;https://converseen.fasterland.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;converseen.fasterland.net&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="176"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;French Translation: &lt;/span&gt;Adrien DAUGABEL - &lt;a href=&quot;mailto:adrien.d@mageialinux-online.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;adrien.d@mageialinux-online.org - &lt;/span&gt;&lt;/a&gt;David GEIGER &lt;a href=&quot;mailto:david.david@mageialinux-online.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;david.david@mageialinux-online.org&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="200"/>
        <source>&lt;strong&gt;Spanish (Chile) Translation: &lt;/strong&gt;Nelson Álvarez Sáez - &lt;a href=&quot;mailto:alvareznelson@gmail.com&quot;&gt;alvareznelson@gmail.com&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="207"/>
        <source>&lt;strong&gt;Turkish Translation: &lt;/strong&gt;Zeugma - &lt;a href=&quot;mailto:sunder67@hotmail.com&quot;&gt;sunder67@hotmail.com&lt;/a&gt; - Sabri Ünal - &lt;a href=&quot;mailto:libreajans@gmail.com&quot;&gt;libreajans@gmail.com&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dialoginfo.cpp" line="41"/>
        <source>Qt Version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dialoginfo.cpp" line="72"/>
        <source>Make a Donation!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dialoginfo.cpp" line="73"/>
        <source>Donate using PayPal, Ko-Fi or Cryptocurrencies.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogMultipageEditor</name>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="20"/>
        <source>Check the pages or subimages you want to import</source>
        <translation>Перевірте сторінки або вкладені зображення, які Ви бажаєте імпортувати</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="42"/>
        <source>Page</source>
        <translation>Сторінка</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="47"/>
        <source>Pixel size</source>
        <translation>Розмір пікселя</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="52"/>
        <source>Density</source>
        <translation>Щільність</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="57"/>
        <source>Depth</source>
        <translation>Глибина</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="93"/>
        <source>Cancel</source>
        <translation>Відміна</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="104"/>
        <source>Import</source>
        <translation>Імпорт</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="121"/>
        <source>Check</source>
        <translation>Перевірити</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="130"/>
        <source>Check all</source>
        <translation>Перевірити все</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="139"/>
        <source>Uncheck</source>
        <translation>Скасувати вибір</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="148"/>
        <source>Uncheck all</source>
        <translation>Скасувати вибір всіх</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="14"/>
        <source>Import multipage document</source>
        <translation>Імпортувати багатосторінковий документ</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="65"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://converseen.fasterland.net/converseen-can-convert-pdf-as-image-files/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;How to enable the PDF conversion?&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="157"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="160"/>
        <source>Open online help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="163"/>
        <source>F1</source>
        <translation type="unfinished">F1</translation>
    </message>
    <message>
        <location filename="../src/dialogmultipageeditor.cpp" line="159"/>
        <source>In order to perform the conversion of &lt;b&gt;PDF&lt;/b&gt; files to images, &lt;b&gt;Ghostscript for Windows&lt;/b&gt; must be installed on your system.&lt;br&gt;&lt;br&gt;             Please install the correct version of &lt;b&gt;Ghostscript&lt;/b&gt;.&lt;br&gt;             Click on the &lt;b&gt;Help&lt;/b&gt; button for more details.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogOptions</name>
    <message>
        <location filename="../ui/dialogoptions.ui" line="129"/>
        <source>Ok</source>
        <translation>ОК</translation>
    </message>
    <message>
        <location filename="../src/dialogoptions.cpp" line="66"/>
        <source>Please, restart Converseen to apply current language!</source>
        <translation>Для зміни мови перезавантажте Converseen!</translation>
    </message>
    <message>
        <location filename="../src/dialogoptions.cpp" line="106"/>
        <source>Please restart Converseen to apply the new theme!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/dialogoptions.cpp" line="145"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="136"/>
        <source>Cancel</source>
        <translation>Відміна</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="26"/>
        <source>Language:</source>
        <translation>Мова:</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="20"/>
        <source>Language</source>
        <translation>Мова</translation>
    </message>
    <message>
        <location filename="../src/dialogoptions.cpp" line="65"/>
        <location filename="../src/dialogoptions.cpp" line="105"/>
        <source>Warning!</source>
        <translation>Попередження!</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="72"/>
        <source>Overwriting settings</source>
        <translation>Перезаписати налаштування</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="14"/>
        <source>Settings</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="46"/>
        <source>Themes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="52"/>
        <source>Style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="78"/>
        <source>As&amp;k first</source>
        <translation>Запитати спочат&amp;ку</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="88"/>
        <source>O&amp;verwrite all existing images</source>
        <translation>Перезаписати &amp;всі існуючі зображення</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="98"/>
        <source>Updates</source>
        <translation>Оновлення</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="104"/>
        <source>Checks for updates automatically</source>
        <translation>Автоматично перевіряти оновлення</translation>
    </message>
</context>
<context>
    <name>DialogQuality</name>
    <message>
        <location filename="../ui/dialogquality.ui" line="456"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="68"/>
        <source>Jpeg compression level</source>
        <translation>Рівень стистення JPEG</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="463"/>
        <source>Cancel</source>
        <translation>Відміна</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="20"/>
        <source>Image settings</source>
        <translation>Налаштування зображення</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="401"/>
        <source>Interpolation</source>
        <translation>Інтерполяція</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="409"/>
        <source>Filter:</source>
        <translation>Фільтр:</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="76"/>
        <source>Quality 1 - 100:</source>
        <translation type="unfinished">Якість 0-100: {1 ?} {100:?}</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="83"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For the JPEG image formats, quality is 1 (lowest image quality and highest compression) to 100 (best quality but least effective compression).&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="86"/>
        <location filename="../ui/dialogquality.ui" line="184"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4; vertical-align:super;&quot;&gt;?&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="166"/>
        <source>Png/Mng compression level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="174"/>
        <source>Quality 0 - 9:</source>
        <translation type="unfinished">Якість 0-100: {0 ?} {9:?}</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="181"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Sets the zlib compression level from 1 to 9 (1 is lowest and 9 is highest).&lt;/p&gt;&lt;p&gt;For compression level 0, the Huffman-only strategy is used, which is fastest but not necessarily the worst compression.&lt;/p&gt;&lt;p&gt;PNG uses a &apos;lossless&apos; compression method, so increasing the compression does NOT reduce your image quality.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="53"/>
        <source>Jpeg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="145"/>
        <source>Png/Mng</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="257"/>
        <source>WebP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="269"/>
        <source>WebP General Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="275"/>
        <source>Enable Lossless Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="284"/>
        <source>Compression Method:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="328"/>
        <source>Quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="347"/>
        <source>%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="361"/>
        <source>Enable Dithering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="431"/>
        <source>Remove image&apos;s metadata</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogShowUpdateMsg</name>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="14"/>
        <source>Dialog</source>
        <translation>Діалог</translation>
    </message>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="20"/>
        <source>TextLabel</source>
        <translation>Надпис</translation>
    </message>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="40"/>
        <source>Don&apos;t show again</source>
        <translation>Не показувати знову</translation>
    </message>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="62"/>
        <source>Update Now</source>
        <translation>Оновити зараз</translation>
    </message>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="69"/>
        <source>Not Now</source>
        <translation>Не зараз</translation>
    </message>
</context>
<context>
    <name>Formats</name>
    <message>
        <location filename="../src/formats.cpp" line="105"/>
        <source>All Supported Filters (%1)</source>
        <translation>Всі підтримувані фільтри (%1)</translation>
    </message>
    <message>
        <location filename="../src/formats.cpp" line="112"/>
        <source>Don&apos;t change the format</source>
        <translation>Не змінювати формат</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.ui" line="184"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="414"/>
        <source>&amp;Edit</source>
        <translation>&amp;Редагувати</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1461"/>
        <source>&amp;Exit</source>
        <translation>&amp;Вихід</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="409"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="424"/>
        <source>&amp;Help</source>
        <translation>&amp;Допомога</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="615"/>
        <source>Show preview</source>
        <translation>Передогляд</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="680"/>
        <location filename="../ui/mainwindow.ui" line="706"/>
        <location filename="../ui/mainwindow.ui" line="732"/>
        <location filename="../ui/mainwindow.ui" line="758"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt; - &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="65"/>
        <source>Conversion Formats</source>
        <translation>Формати перетворення</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="280"/>
        <source>#_copy</source>
        <translation>#_копія</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="181"/>
        <source>Open output directory</source>
        <translation>Відкрити теку призначення</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="90"/>
        <source>Show image settings dialog...</source>
        <translation>Показати діалог налаштувань зображень…</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="817"/>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="419"/>
        <source>&amp;Actions</source>
        <translation>&amp;Дії</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="244"/>
        <source>Rename:</source>
        <translation>Перейменувати:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="169"/>
        <source>Save in:</source>
        <translation>Зберегти в:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="155"/>
        <source>Output options</source>
        <translation>Вихідні параметри</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="93"/>
        <source>Images settings</source>
        <translation>Налаштування зображень</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="507"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Preview:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Передогляд:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="32"/>
        <source>Converseen</source>
        <translation>Converseen</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="73"/>
        <source>Convert to:</source>
        <translation>Перетворити в:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="824"/>
        <source>Height:</source>
        <translation>Висота:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="195"/>
        <source>Image&apos;s directory</source>
        <translation>Тека зображень</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="124"/>
        <source>Replace transparent background</source>
        <translation>Замінити прозоре тло</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="131"/>
        <source>Choose color</source>
        <translation>Вибрати колір</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="316"/>
        <source>File Overwrite Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="324"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If the processed output file has the same name as an existing file in the destination folder, you will be prompted to choose an action manually.&lt;/p&gt;&lt;p&gt;You can either rename it or overwrite the existing file.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="327"/>
        <source>Always Ask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="350"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If the processed output file has the same name as an existing file in the same folder, the conversion process will automatically &lt;span style=&quot; font-weight:700;&quot;&gt;skip&lt;/span&gt; it to &lt;span style=&quot; font-weight:700;&quot;&gt;preserve&lt;/span&gt; the one in the destination directory.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="353"/>
        <source>Skip Existing Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="376"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If the processed output file has the same name as an existing file in the same folder, the conversion process will &lt;span style=&quot; font-weight:700;&quot;&gt;overwrite&lt;/span&gt; the original file, &lt;span style=&quot; font-weight:700;&quot;&gt;permanently deleting it&lt;/span&gt;.&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Please, use caution when selecting this option!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="379"/>
        <source>Overwrite Existing Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="669"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Type:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Тип:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="695"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;File size:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Розмір файлу:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="721"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Image size:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Розмір зображення:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="747"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Image resolution:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Роздільна здатність зображення:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="801"/>
        <source>Scale image</source>
        <translation>Масштабувати зображення</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1008"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;0 x 0 pixel&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;0 x 0 піксель&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1021"/>
        <source>Mantain aspect ratio</source>
        <translation>Зберегти пропорції</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1042"/>
        <source>Resolution</source>
        <translation>Роздільна здатність</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1058"/>
        <source>Resolution X:</source>
        <translation>Роздільна здатність Х:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1065"/>
        <source>Resolution Y:</source>
        <translation>Роздільна здатність Y:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1328"/>
        <source>toolBar</source>
        <translation>Смужка інструментів </translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1358"/>
        <source>&amp;Open images</source>
        <translation>Відкрити з&amp;ображення</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1361"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+О</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1370"/>
        <source>&amp;Add images</source>
        <translation>&amp;Додати зображення</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1373"/>
        <source>Ctrl+Alt+O</source>
        <translation>Ctrl+Alt+О</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1382"/>
        <source>&amp;Remove images</source>
        <translation>&amp;Видалити зображення</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1385"/>
        <source>Remove selected pictures</source>
        <translation>Видалити помічені зображення</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1388"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1397"/>
        <source>Remove &amp;all</source>
        <translation>В&amp;идалити все</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1400"/>
        <source>Remove all pictures</source>
        <translation>Видалити всі зображення</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1403"/>
        <source>Alt+Del</source>
        <translation>Alt+Del</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1412"/>
        <source>&amp;Check</source>
        <translation>&amp;Позначити</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1415"/>
        <source>Check selected items</source>
        <translation>Позначити виділені елементи</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1418"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1427"/>
        <source>Check a&amp;ll</source>
        <translation>Відмінити &amp;все</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1430"/>
        <source>Check all items</source>
        <translation>Відмінити всі елементи</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1433"/>
        <source>Ctrl+Alt+H</source>
        <translation>Ctrl+Alt+H</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1442"/>
        <source>&amp;Convert</source>
        <translation>&amp;Перетворити</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1445"/>
        <source>Start the conversion process</source>
        <translation>Почати процес перетворення</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1448"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1453"/>
        <source>&amp;Settings</source>
        <translation>&amp;Налаштування</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1456"/>
        <source>Open the settings dialog</source>
        <translation>Відкрити діалог налаштувань</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1469"/>
        <source>Uncheck all &amp;items</source>
        <translation>Скасувати вибір всі&amp;х</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1472"/>
        <source>Ctrl+Alt+J</source>
        <translation>Ctrl+Alt+J</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1477"/>
        <source>&amp;Uncheck Items</source>
        <translation>&amp;Скасувати вибір</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1480"/>
        <source>Uncheck selected items</source>
        <translation>Скасувати вибір помічених елементів</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1483"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1488"/>
        <source>&amp;About</source>
        <translation>&amp;Про програму</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1553"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1558"/>
        <source>Invert Checked Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1561"/>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="783"/>
        <source>Dimensions</source>
        <translation>Розміри</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1128"/>
        <location filename="../ui/mainwindow.ui" line="1134"/>
        <source>Rotate and flip</source>
        <translation>Обертання і відображення</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1149"/>
        <source>Rotate image:</source>
        <translation>Повернути зображення:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1158"/>
        <source>No rotation</source>
        <translation>Не обертати</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1230"/>
        <source>Flip image:</source>
        <translation>Перевернути зображення:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1239"/>
        <source>No flip</source>
        <translation>Не відображати</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1257"/>
        <source>Horizontally</source>
        <translation>Горизонтально</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1271"/>
        <source>Vertically</source>
        <translation>Вертикально</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="287"/>
        <source>Start with:</source>
        <translation>Почати з:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1510"/>
        <source>Import PDF file</source>
        <translation>Імпортувати файл PDF</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1515"/>
        <source>Import windows icon (*.ico)</source>
        <translation>Імпортувати іконку windows (*.ico)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1518"/>
        <source>Import windows icon (*.ico *.icon)</source>
        <translation>Імпортувати іконку windows (*.ico *.icon)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="253"/>
        <source>Prefi&amp;x/Suffix</source>
        <translation>Префі&amp;кс/Суфікс</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="263"/>
        <source>Progressi&amp;ve Number</source>
        <translation>&amp;Порядковий номер</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1505"/>
        <source>&amp;Report bug...</source>
        <translation>&amp;Повідомити про помилку...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1526"/>
        <source>Check if a new version of Converseen is available</source>
        <translation>Перевіряти наявність нової версії Converseen</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1523"/>
        <source>&amp;Check for updates</source>
        <translation>&amp;Перевірити наявність нової версії</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="458"/>
        <source>Actio&amp;ns Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1175"/>
        <source>+ &amp;90°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1189"/>
        <source>- 9&amp;0°</source>
        <translation type="unfinished">- 90° {9&amp;0°?}</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1205"/>
        <source>&amp;180°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1464"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1535"/>
        <location filename="../ui/mainwindow.ui" line="1538"/>
        <source>Import directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1550"/>
        <source>Open online help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="951"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Load Image Sizes&lt;/span&gt;&lt;/p&gt;&lt;p&gt;If &apos;&lt;span style=&quot; font-weight:700;&quot;&gt;px&apos;&lt;/span&gt; is selected, the original image sizes will be loaded into the &lt;span style=&quot; font-weight:700;&quot;&gt;Width/Height&lt;/span&gt; fields. &lt;/p&gt;&lt;p&gt;If &lt;span style=&quot; font-weight:700;&quot;&gt;&apos;%&apos;&lt;/span&gt; is selected, it restores the &lt;span style=&quot; font-weight:700;&quot;&gt;Width/Height&lt;/span&gt; fields to &lt;span style=&quot; font-weight:700;&quot;&gt;100%&lt;/span&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="965"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Link Aspect Ratio with Selected Image&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Automatically adjusts the aspect ratio values when you enter a value in the &lt;span style=&quot; font-weight:700;&quot;&gt;Width/Height&lt;/span&gt; fields.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1497"/>
        <source>&amp;Donate!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1500"/>
        <source>Donate via Paypal, Ko-Fi, Cryptocurrencies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1547"/>
        <source>&amp;Online Help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindowImpl</name>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="257"/>
        <source>Open Image</source>
        <translation>Відкрити зображення</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="473"/>
        <source>Set an output directory!</source>
        <translation>Встановити вихідну теку!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="687"/>
        <source>Processing finished!</source>
        <translation>Обробка завершена!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="1186"/>
        <source>Suggest a new name!</source>
        <translation>Введіть нове ім&apos;я!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="481"/>
        <source>No images to convert!</source>
        <translation>Немає зображень для перетворення!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="1210"/>
        <location filename="../src/mainwindowimpl.cpp" line="1215"/>
        <source>Warning!</source>
        <translation>Попередження!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="1187"/>
        <source>New name:</source>
        <translation>Нове ім&apos;я:</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="457"/>
        <location filename="../src/mainwindowimpl.cpp" line="463"/>
        <location filename="../src/mainwindowimpl.cpp" line="472"/>
        <location filename="../src/mainwindowimpl.cpp" line="476"/>
        <location filename="../src/mainwindowimpl.cpp" line="480"/>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="477"/>
        <source>No image checked!</source>
        <translation>Зображення не вибрані!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="498"/>
        <source>Processing...</source>
        <translation>Обробка…</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="271"/>
        <location filename="../src/mainwindowimpl.cpp" line="741"/>
        <source>Open Directory</source>
        <translation>Відкрити теку</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="417"/>
        <source>n/a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="458"/>
        <source>The output directory doesn&apos;t exists! Would you create it?</source>
        <translation>Тека призначення не створена! Створити теку?</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="464"/>
        <source>The directory cannot be created!</source>
        <translation>Тека не створена!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="676"/>
        <source>Skipped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="678"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="1192"/>
        <source>Please, specify a name!</source>
        <translation>Будь ласка, вкажіть ім&apos;я!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="1193"/>
        <source>You should specify a name.
Click Retry to specify a new name.
Click Ignore to cancel this operation.
Click Abort to cancel all operations.</source>
        <translation>Ви повинні вказати ім&apos;я.
Натисніть Повторити щоб вказати нове ім&apos;я.
Натисніть Ігнорувати для відміни цієї операції.
Натисніть Скасувати для відміни усіх операцій.</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="1211"/>
        <source>The filename should not be empty!</source>
        <translation>І&apos;мя файлу не може бути порожнім!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="1216"/>
        <source>The name chosen is identical to the initial one. Do you want to overwrite the original file?</source>
        <translation>Выбране і&apos;мя співпадає з початковим файлом. Ви бажаєте замінити оригінальний файл?</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="1232"/>
        <source>Aborted!</source>
        <translation>Скасовано!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="860"/>
        <location filename="../src/mainwindowimpl.cpp" line="878"/>
        <location filename="../src/mainwindowimpl.cpp" line="1051"/>
        <location filename="../src/mainwindowimpl.cpp" line="1108"/>
        <source>Preview</source>
        <translation>Передогляд</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="307"/>
        <source>Open Icon file</source>
        <translation>Відкрити файл іконки</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="307"/>
        <source>Microsoft icon (*.ico *.icon)</source>
        <translation>Значок Microsoft (*.ico *.icon)</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="318"/>
        <source>Open Pdf file</source>
        <translation>Відкрити Pdf файл</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="318"/>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="328"/>
        <source>Analyzing the file. It may take a while, please wait...</source>
        <translation>Аналіз файлу. Це може зайняти деякий час, будь ласка, зачекайте...</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="671"/>
        <source>Converted</source>
        <translation type="unfinished">Перетворено</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="278"/>
        <source>Do you want to import subfolders as well?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="352"/>
        <source>You are going to import %1 directories. Do you want to import subfolders as well?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PixTreeWidget</name>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="42"/>
        <source>File name</source>
        <translation>Ім&apos;я файлу</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="44"/>
        <source>Image size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="45"/>
        <source>Resolution</source>
        <translation type="unfinished">Роздільна здатність</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="47"/>
        <source>File path</source>
        <translation>Шлях до файлу</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="46"/>
        <source>File size</source>
        <translation>Розмір файлу</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="41"/>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="40"/>
        <source>To convert</source>
        <translation>Перетворювати</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="43"/>
        <source>Image type</source>
        <translation>Тип зображення</translation>
    </message>
</context>
<context>
    <name>Translator</name>
    <message>
        <location filename="../src/translator.cpp" line="129"/>
        <location filename="../src/translator.cpp" line="142"/>
        <source>English</source>
        <translation>Українська</translation>
    </message>
</context>
<context>
    <name>UpdateChecker</name>
    <message>
        <location filename="../src/updatechecker.cpp" line="81"/>
        <source>New version is available!</source>
        <translation>Маємо нову версію!</translation>
    </message>
    <message>
        <location filename="../src/updatechecker.cpp" line="82"/>
        <source>A new version of %1 is available!
Would you download it?</source>
        <translation>Маємо нову версію %1!
Ви бажаєте завантажити її?</translation>
    </message>
</context>
<context>
    <name>myLabelPreviewer</name>
    <message>
        <location filename="../src/mylabelpreviewer.cpp" line="53"/>
        <source>Preview</source>
        <translation>Передогляд</translation>
    </message>
</context>
</TS>
